@@ -56,7 +56,11 @@ def get_token_count(text: str) -> int:
         manager = _get_model_manager()
         result = manager.count_tokens(text, OpenAIModelEnum.GPT_4.value)
         token_count = result["token_count"]
-        return int(token_count) if isinstance(token_count, int | float) else max(1, len(text) // 4)
+        return (
+            int(token_count)
+            if isinstance(token_count, int | float)
+            else max(1, len(text) // 4)
+        )
     except Exception:
         # Fallback simples se tiktoken não estiver disponível
         return max(1, len(text) // 4)
